@@ -24,8 +24,3 @@ def test_save_range():
     end_date = datetime.date.today()
     for range_type in (jsm.DAILY, jsm.WEEKLY, jsm.MONTHLY):
         c.save_historical_prices(tempfile.mktemp(dir='/tmp/'), CCODE, range_type, start_date, end_date)
-
-def test_save_all():
-    c = jsm.QuotesCsv()
-    for range_type in (jsm.DAILY, jsm.WEEKLY, jsm.MONTHLY):
-        c.save_historical_prices(tempfile.mktemp(dir='/tmp/'), CCODE, range_type, all=True)
